pub enum Expr {
Column(String),
Literal(Literal),
BinaryOp {
left: Box<Expr>,
op: BinaryOperator,
right: Box<Expr>,
},
UnaryOp {
op: UnaryOperator,
expr: Box<Expr>,
},
Function {
name: String,
args: Vec<Expr>,
},
Case {
when_then: Vec<(Expr, Expr)>,
else_expr: Option<Box<Expr>>,
},
Cast {
expr: Box<Expr>,
data_type: ExprDataType,
},
Coalesce {
exprs: Vec<Expr>,
},
}Expand description
Represents an expression that can be used in a distributed computation
Variants
Column(String)
Column reference
Literal(Literal)
Literal value
BinaryOp
Binary operation
UnaryOp
Unary operation
Function
Function call
Case
Case statement
Fields
Cast
CAST expression
Coalesce
COALESCE expression
Implementations
Sourceimpl Expr
impl Expr
Sourcepub fn binary(left: Expr, op: BinaryOperator, right: Expr) -> Self
pub fn binary(left: Expr, op: BinaryOperator, right: Expr) -> Self
Creates a binary operation
Sourcepub fn unary(op: UnaryOperator, expr: Expr) -> Self
pub fn unary(op: UnaryOperator, expr: Expr) -> Self
Creates a unary operation
Sourcepub fn case(when_then: Vec<(Expr, Expr)>, else_expr: Option<Expr>) -> Self
pub fn case(when_then: Vec<(Expr, Expr)>, else_expr: Option<Expr>) -> Self
Creates a CASE expression
Sourcepub fn cast(expr: Expr, data_type: ExprDataType) -> Self
pub fn cast(expr: Expr, data_type: ExprDataType) -> Self
Creates a CAST expression
Sourcepub fn lte(self, other: Expr) -> Self
pub fn lte(self, other: Expr) -> Self
Checks if this expression is less than or equal to another
Sourcepub fn gte(self, other: Expr) -> Self
pub fn gte(self, other: Expr) -> Self
Checks if this expression is greater than or equal to another
Sourcepub fn is_not_null(self) -> Self
pub fn is_not_null(self) -> Self
Checks if this expression is NOT NULL
Sourcepub fn to_boolean(self) -> Self
pub fn to_boolean(self) -> Self
Casts this expression to boolean
Sourcepub fn to_integer(self) -> Self
pub fn to_integer(self) -> Self
Casts this expression to integer
Sourcepub fn to_timestamp(self) -> Self
pub fn to_timestamp(self) -> Self
Casts this expression to timestamp